`snowflake.core` is the subpackage providing Python access to Snowflake entity metadata.

You can use it to interact with Snowflake resources, creating, deleting, modifying them, and more. 

[Developer guide](https://docs.snowflake.com/developer-guide/snowflake-python-api/snowflake-python-overview)

[API reference](https://docs.snowflake.com/developer-guide/snowflake-python-api/reference/latest/index)
